---
date: 2016-04-09T16:50:16+02:00
title: Lora Level Transmitter
weight: 1
---

### Safety information

{{% notice warning %}}
Read these instructions carefully and look at the equipment to become familiar
with the device before trying to install, operate, service or maintain it. The
following special messages may appear throughout this bulletin or on the
equipment to warn of potential hazards or to call attention to information that
clarifies or simplifies a procedure.
{{% /notice %}}

<p><i class="fas fa-exclamation-triangle"></i> The input pins do not have polarity protection, any reverse polarity connection can damage the device.</p>

### Overview

The Dakton Lora transmitter DK-LORALEVEL is a versatile device for fuel and liquid level and temperature monitoring.

### Device Features

+ Lora and LoraWan protocols.
+ Low power consumption.
+ Frequency EU and US versions.
+ 4-20mA Industrial input.
+ MODBUS RS485 support.
+ Temperature bus. (* optional)
+ 12 Volt and 24 Volt output versions.
+ Battery life up to 7 years.
+ External antenna. (* optional)
 



#### Specifications
| Parameter     |      Specification    |
| ------------- | ----------------------- | 
| 4-20 Accuracy                 | ±0.05% of range (16bit)                                           |
| Operating Voltage             | 1x Dakton battery 3.3V                                            |
| Idle Current consumption      | ±4-50µV                                                           |
| Battery Measurement Accuracy  | ±0.1V                                                             |
| Antenna Type                  | Build-in or *External                                             |
| Spread Technique              | LoRa/FSK                                                          |
| Available Frequency           | US915 AU915 AS923  EU868 KR920 CN470 Configured before shipment   |
| Operating Humidity            | ＜90%RH                                                           |
| Operating Temperature         | -20°C ～ 55°C                                                     |
| Storage Temperature           | -10°C ～ 70°C                                                     |
| Output Voltage                | 12V/24V Configured before shipment                                |
| Max. Ouput Current            | 120mA at 12V                                                      |
| Configuration                 | PC (with cable) or Mobile (with Conf adapter)                     |



### Wiring Specs

![dklora_spec](_files/PCB_DESCRIPTION_white.png?width=200px&classes=border,shadow,floatleft "Device")
![dklora_types](_files/wiring_types.png?width=200px&classes=border,shadow,floatleft "Types")
![dklora_temp](_files/wiring_temperature.png?width=200px&classes=border,shadow,floatleft "Temperature")



### Configuration & Upgrade Inteface

#### PC Interface


<p>To modify the factory configuration you will need the configuration cable DK-LORAINTCABLE and software WonkaTool</p>
<p><a href="_files/WonkaTool.exe" target="_blank" title="WonkaTool">Download WonkaTool</a></p>

CLI Commands via Serial Interface (baudrate:115200):

{{% notice note %}}
Enable CLI putting a magnet over the "Service Magnet Activation" at the top of the device, then press "RESET".  
(MAGNET + RESET)
{{% /notice %}}
Once the CLI is enabled the LED will be switched to WHITE permanent color.
Leave CLI with "reboot" command or pressing "RESET" button.

|        Command        |      Description              |
| --------------------- | ----------------------------- |
| get_conf              | List Current Configuration    | 
| reboot                | System Reboot                 | 
| set_freq              | Set Frequency                 |     
| set_bandw             | Set Bandwidth                 | 
| set_sf                | Set Spreading Factor          | 
| set_txpwr             | Set TX Power                  | 
| set_sleepint          | Set Sleep Time Between Msgs   | 
| set_msgformat         | Set Msg Format                | 
| set_msgprefix         | Set Msg Prefix                |
| get_stats             | Show Statistics               |
| clear_stats           | Clear Statistics              |
| freset                | Factory Reset                 | 





#### Wireless Interface <i class="fas fa-desktop"></i> & <i class="fas fa-mobile-alt"></i>


<p>Connect the Wireless interface and power it up.</p> 

Take you Cellular or PC and connect it to the WiFi network **"Dakton LoraConfig"** , after that open your browser <a href="http://192.168.4.1" target="_blank" title="Latest Firmware">http://192.168.4.1</a>

**Configuration WebSite** 
* Username: ```admin```
* Password: ```dakton1234```

Browse and change the configuration field you are looking for.

<br><br>

#### Default Configuration LoraPrivate

|     Items             |      Default          |
| --------------------- | --------------------- |
| Sending Interval      | 15 minutes            | 
| Spreading Factor      | SF7                   |
| Lora Bandwidth        | 125000                |
| TX Output Power       | 20 dBm                |
| EU Frequency          | 902.3 MHz             |
| US Frequency          | 868.3 MHz             |
| Message Format        | Json String           |
| Message Prefix        | \<DK>                 |
| Temperature           | Disabled              |
| Sensor Type           | Auto-detection        |


### Message Output Format (Lora Private)


#### Json String Type:

The ouput packet is XOR encrypted by a 6 byte Char.

Packet Format:  **XOREncryption("PREFIX" + "PAYLOAD")**

Payload Format:
~~~
{
    "s":"SerialNumber",
    "l":"Level Float Value",     
    "b":"Battery Level"          (battery level range 0-254, 0=Empty 254=Full)
}

The Payload should looks like:

{
    "s":"04D1A4",
    "l":"12.23",
    "b":"240"
}
~~~




### Download latest Firmware

#### Lora Private
<p>Lora US:  <a href="_files/DK-LORALEVEL_US.bin" target="_blank" title="Latest Firmware">Download</a></p>
<p>Lora EU:  <a href="_files/DK-LORALEVEL_EU.bin" target="_blank" title="Latest Firmware">Download</a></p>

#### LoraWan
<p>LoraWan US:  <a href="_files/DK-LORALEVEL_LORAWAN_US.bin" target="_blank" title="Latest Firmware">Download</a></p>
<p>LoraWan EU:  <a href="_files/DK-LORALEVEL_LORAWAN_EU.bin" target="_blank" title="Latest Firmware">Download</a></p>


